local L = LibStub("AceLocale-3.0"):GetLocale("EasyDKP")

function EasyDKP:GetOptions()
	local options = { 
		name = "EasyDKP",
		handler = EasyDKP,
		type='group',
		childGroups ='tree',
		args = {
			minquality = {
				type = 'range',
				name = L["Min Quality"],
				desc = L["help_minquality"],
				min = 1,
				max = 6,
				step = 1,
				get = "GetMinQuality",
				set = "SetMinQuality",
				order = 1,
			},
			maxquality = {
				type = 'range',
				name = L["Max Quality"],
				desc = L["help_maxquality"],
				min = 1,
				max = 6,
				step = 1,
				get = "GetMaxQuality",
				set = "SetMaxQuality",
				order = 2,
			},
			doublecost = {
				type = 'toggle',
				name = L["Double Cost"],
				desc = L["help_doublecost"],
				get = "GetDoubleCost",
				set = "SetDoubleCost",
				order = 3,
			},
			list = {
				type = 'execute',
				name = L["Show List"],
				desc = L["help_displayList"],
				func = "ShowOptionsFrame",
				order = 4,
			},
			changes = {
				type = 'execute',
				name = L["Show Changes"],
				desc = L["help_changes"],
				func = "ShowChanges",
				order = 5,
			},
			add = {
				type = 'input',
				name = L["Add dkp to player"],
				usage = L["help_add"],
				pattern = "(%w+) (%d+)",
				validate = "CheckAddSubtract",
				set = "NoNeedtoSet",
				guiHidden = true,
				order = 6,
			},
			subtract = {
				type = 'input',
				name = L["Subtract dkp from player"],
				usage = L["help_subtract"],
				pattern = "(%w+) (%d+)",
				validate = "CheckAddSubtract",
				set = "NoNeedtoSet",
				guiHidden = true,
				order = 7,
			},
			date = {
				type = 'execute',
				name = L["Display Download Date"],
				desc = L["help_date"],
				func = "ShowDate",
				order = 8,
			},
			debug = {
				type = 'toggle',
				name = L["Debug mode"],
				desc = L["help_debug"],
				get = "GetDebug",
				set = "SetDebug",
				order = 9,
			},
			config = {
				type = 'execute',
				name = L["Configure Options"],
				desc = L["help_config"],
				func = "OpenConfig",
				guiHidden = true,
				order = 10,
			},
--~ 			news = {
--~ 				type = 'execute',
--~ 				name = L["Display News"],
--~ 				desc = L["help_news"],
--~ 				func = function() self:News(true); end,
--~ 				order = 14,
--~ 			},
			version = {
				type = 'execute',
				name = L["Version"],
				desc = L["help_version"],
				func = "DisplayVersion",
				order = 12,
			},
			help = {
				type = 'description',
				name = L["help"],
				guiHidden = true,
				order = 13,
			},
		},
	}
	return options
end

function EasyDKP:GetDebug()
	return self.db.profile.debug
end

function EasyDKP:SetDebug()
	self.db.profile.debug = not self.db.profile.debug
	if (self.db.profile.debug) then
		self:Print(L["config_debug_on"])
	else
		self:Print(L["config_debug_off"])
	end
end

function EasyDKP:GetDoubleCost()
	return self.db.profile.doublecost
end

function EasyDKP:SetDoubleCost()
	self.db.profile.doublecost = not self.db.profile.doublecost
	if (self.db.profile.doublecost) then
		self:Print(L["config_doublecost_on"])
	else
		self:Print(L["config_doublecost_off"])
	end
end

function EasyDKP:GetMinQuality()
	return self.db.profile.minquality
end

function EasyDKP:SetMinQuality(info, newvalue)
	self.db.profile.minquality = newvalue
	if newvalue > self.db.profile.maxquality then
		SetMaxQuality(info, newvalue)
	end
	self:Print(L["config_minquality"]..EasyDKP.quality[newvalue].text)
end

function EasyDKP:GetMaxQuality()
	return self.db.profile.maxquality
end

function EasyDKP:SetMaxQuality(info, newvalue)
	self.db.profile.maxquality = newvalue
	if newvalue < self.db.profile.minquality then
		SetMinQuality(info, newvalue)
	end
	self:Print(L["config_maxquality"]..EasyDKP.quality[newvalue].text)
end

function EasyDKP:OpenConfig()
	if InterfaceOptionsFrame_OpenToCategory then
	    InterfaceOptionsFrame_OpenToCategory("EasyDKP");
    else
        InterfaceOptionsFrame_OpenToFrame("EasyDKP");
    end
end

function EasyDKP:DisplayVersion()
	self:Print(self.version)
end

function EasyDKP:NoNeedtoSet()
	-- dummy function as we are using AceConfig input type as a command line text command with nothing to set
end

function EasyDKP:ShowDate()
	if dkp_info and dkp_info["date"] then
		self:Print("File download date is "..dkp_info["date"])
	else
		self:Print("File download date not found")
	end
end